@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use URI();
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -103,6 +103,11 @@ sub crl_revocation_status {
     return $self->{crlRevocationStatus};
 }
 
+sub must_staple {
+    my ($self) = @_;
+    return $self->{mustStaple};
+}
+
 1;
 __END__
 
@@ -112,7 +117,7 @@ WebService::SSLLabs::Cert - Cert object
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =head1 SUBROUTINES/METHODS
 
@@ -246,6 +251,20 @@ list of certificate issues, one bit per issue:
 
 true if the certificate contains an embedded SCT; false otherwise.
 
+=head2 must_staple
+
+a number that describes the must staple feature extension status
+
+=over 2
+
+=item 0 - not supported
+
+=item 1 - Supported, but OCSP response is not stapled
+
+=item 2 - Supported, OCSP response is stapled
+
+=back
+
 =head1 DIAGNOSTICS
 
 None
