@@ -10,7 +10,7 @@ use WebService::SSLLabs::Chain();
 use WebService::SSLLabs::Key();
 use WebService::SSLLabs::DrownHost();
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -301,6 +301,16 @@ sub drown_vulnerable {
     return $self->{drownVulnerable} ? 1 : 0;
 }
 
+sub protocol_intolerance {
+    my ($self) = @_;
+    return $self->{protocolIntolerance};
+}
+
+sub misc_intolerance {
+    my ($self) = @_;
+    return $self->{miscIntolerance};
+}
+
 1;
 __END__
 
@@ -310,7 +320,7 @@ WebService::SSLLabs::EndpointDetails - EndpointDetails object
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =head1 SUBROUTINES/METHODS
 
@@ -638,6 +648,40 @@ true if error occurred in drown test.
 
 true if server vulnerable to drown attack.
 
+=head2 protocol_intolerance
+
+indicates protocol version intolerance issues
+
+=over 2
+
+=item bit 0 (1) - TLS 1.0
+
+=item bit 1 (2) - TLS 1.1
+
+=item bit 2 (4) - TLS 1.2
+
+=item bit 3 (8) - TLS 1.3
+
+=item bit 4 (16) - TLS 1.152
+
+=item bit 5 (32) - TLS 2.152
+
+=back
+
+=head2 misc_intolerance
+
+indicates protocol version intolerance issues
+
+=over 2
+
+=item bit 0 (1) - extension intolerance
+
+=item bit 1 (2) - long handshake intolerance
+
+=item bit 2 (4) - long handshake intolerance workaround success
+
+=back
+
 =head1 DIAGNOSTICS
 
 None
